@@ -4,15 +4,14 @@ import time
 import tempfile
 import shutil
 from zipfile import ZipFile, ZIP_DEFLATED, ZIP_STORED, BadZipFile
-from multiprocessing.pool import ThreadPool
 from functools import partial
 from pathlib import Path
 
-from PIL import Image
+from PIL import Image, UnidentifiedImageError
 
 from reCBZ.formats import *
 from reCBZ.config import Config
-from reCBZ.util import mylog, MP_run_tasks, SIGNINT_ctrl_c, human_sort
+from reCBZ.util import mylog, map_workers, worker_sigint_CTRL_C, human_sort
 
 # TODO:
 # include docstrings
@@ -71,6 +70,13 @@ class Page():
     def size(self):
         return self.img.size
 
+    @property
+    def landscape(self):
+        if self.size[0] > self.size[1]:
+            return True
+        else:
+            return False
+
     def save(self, dest):
         self.fmt.save(self.img, dest)
         self.fp = Path(dest)
@@ -99,17 +105,16 @@ class Archive():
         else:
             raise ValueError(f"{filename}: invalid path")
         self._source_stem = self.source_path.stem
-        self.opt_parallel = Config.parallel
-        self.opt_ignore = Config.ignore
-        self._zip_compress = Config.compresszip
-        self._fmt_blacklist = Config.blacklistedfmts
-        self._fmt_samples = Config.samplescount
-        self._pages_format = Config.imageformat
-        self._pages_quality = Config.quality
-        self._pages_size = Config.resolution
+        self.opt_ignore = Config.ignore_err
+        self._zip_compress = Config.compress_zip
+        self._fmt_blacklist = Config.blacklisted_fmts
+        self._fmt_samples = Config.samples_count
+        self._pages_format = Config.img_format
+        self._pages_quality = Config.img_quality
+        self._pages_size = Config.img_size
         self._pages_bw = Config.grayscale
-        self._pages_noup = Config.noupscale
-        self._pages_nodown = Config.nodownscale
+        self._pages_noup = Config.no_upscale
+        self._pages_nodown = Config.no_downscale
         self._pages_filter = Config.resamplemethod
         self._index:list = []
         self._chapter_lengths = []
@@ -122,7 +127,7 @@ class Archive():
         return self._index
 
     def fetch_chapters(self):
-        # ensure it's a copy, so we can't delete the actual objects
+        # ensure it's a copy, so we can't delete the original objects
         index_copy = [page for page in self.fetch_pages()]
         if len(self._chapter_lengths) == 0:
             self._chapter_lengths = [len(index_copy)]
@@ -197,16 +202,14 @@ class Archive():
         return tuple(self.fetch_pages())
 
     def convert_pages(self, fmt=None, quality=None, grayscale=None, size=None) -> tuple:
+        # TODO assert values are the right type
         if fmt is not None: self._pages_format = fmt
         if quality is not None: self._pages_quality = int(quality)
         if grayscale is not None: self._pages_bw = bool(grayscale)
         if size is not None: self._pages_size = size
 
         source_pages = self.fetch_pages()
-        if self.opt_parallel:
-            results = MP_run_tasks(self._convert_page, source_pages)
-        else:
-            results = map(self._convert_page, source_pages)
+        results = map_workers(self._convert_page, source_pages)
         self._index = [page for page in results if page]
         return tuple(self._index)
 
@@ -216,10 +219,7 @@ class Archive():
             Path.mkdir(fmtdir)
 
             pfunc = partial(self._convert_page, savedir=fmtdir, format=fmt)
-            if self.opt_parallel:
-                results = MP_run_tasks(pfunc, sample_pages)
-            else:
-                results = map(pfunc, sample_pages)
+            results = map_workers(pfunc, sample_pages)
 
             converted_pages = [page for page in results if page]
             nbytes = sum(page.fp.stat().st_size for page in converted_pages)
@@ -229,6 +229,7 @@ class Archive():
         # manually call extract so we don't overwrite _pages cache
         source_pages = self.extract(count=self._fmt_samples)
         nbytes = sum(page.fp.stat().st_size for page in source_pages)
+        mylog(f'reference format: {source_pages[0].name}')
         source_fmt = source_pages[0].fmt
         source_fsize = [nbytes, f'{Archive._SOURCE_NAME} ({source_fmt.desc})',
                         source_fmt.name]
@@ -237,11 +238,8 @@ class Archive():
         # one thread per individual format. n processes per thread
         fmt_fsizes = []
         pfunc = partial(compute_single_fmt, source_pages, self._cachedir)
-        if self.opt_parallel:
-            with ThreadPool(processes=len(self._valid_page_formats)) as Tpool:
-                fmt_fsizes.extend(Tpool.map(pfunc, self._valid_page_formats))
-        else:
-            fmt_fsizes.extend(map(pfunc, self._valid_page_formats))
+        results = map_workers(pfunc, self._valid_page_formats, multithread=True)
+        fmt_fsizes.extend(results)
 
         # finally, compare
         # in multidepth lists, sorted compares the first element by default :)
@@ -335,7 +333,7 @@ class Archive():
         # TODO make public as add_page, append to self._pages
         return Page(fp)
 
-    @SIGNINT_ctrl_c
+    @worker_sigint_CTRL_C
     def _convert_page(self, source:Page, savedir=None, format=None): #-> None | Str:
         start_t = time.perf_counter()
         LossyFmt.quality = self._pages_quality
@@ -348,7 +346,7 @@ class Archive():
             log_buff = f'/open:  {page.fp}\n'
             source_fmt = page.fmt
             img = page.img
-        except IOError as err:
+        except (IOError, UnidentifiedImageError) as err:
             if self.opt_ignore:
                 mylog(f"{page.fp}: can't open file as image, ignoring...'")
                 return None
@@ -380,12 +378,12 @@ class Archive():
         if self._pages_bw:
             log_buff += '|trans: mode L\n' # me lol
             img = img.convert('L')
-        if all(self._new_page_size):
-            log_buff += f'|trans: resize to {self._new_page_size}\n'
+        if all(self._pages_size):
+            log_buff += f'|trans: resize to {self._pages_size}\n'
             width, height = img.size
-            new_size = self._new_page_size
+            new_size = self._pages_size
             # preserve aspect ratio for landscape images
-            if width > height:
+            if page.landscape:
                 new_size = new_size[::-1]
             n_width, n_height = new_size
             # downscaling
@@ -432,17 +430,6 @@ class Archive():
         assert len(valid_fmts) >= 1, "valid_formats is 0"
         return valid_fmts
 
-    @property
-    def _new_page_size(self) -> tuple:
-        default_value = (0,0)
-        newsize = self._pages_size.lower().strip()
-        try:
-            newsize = tuple(map(int,newsize.split('x')))
-            assert len(newsize) == 2
-            return newsize
-        except (ValueError, AssertionError):
-            return default_value
-
     @classmethod
     def cleanup(cls):
         tempdir = Path(tempfile.gettempdir())
